<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Demo
 */

function customizer_library_demo_options() {

	// Theme defaults
	$primary_color = '#00adef';
	$secondary_color = '#666';

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// More Examples
	$section = 'examples';

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Theme Settings', 'fastvideo-pro' ),
		'priority' => '10'
	);

	$options['logo'] = array(
		'id' => 'logo',
		'label'   => __( 'Logo', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/logo.png'
	);

	$options['favicon'] = array(
		'id' => 'favicon',
		'label'   => __( 'Favicon', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => ''
	);	
	
	$layout_choices = array(
		'choice-1' => 'Responsive Layout',
		'choice-2' => 'Fixed Layout'
	);

	$featured_num_choices = array(
		'1','2', '3','4','5','6','7','8','9'													
	);

	$date_format_choices = array(
		'choice-1' => 'xx days ago',
		'choice-2' => 'WordPress Settings'
	);	

	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Site Layout', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $layout_choices,
		'default' => 'choice-1'
	);

	$options['theme-color'] = array(
		'id' => 'theme-color',
		'label'   => __( 'Theme Color', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $primary_color // hex
	);	

	$options['primary-font'] = array(
		'id' => 'primary-font',
		'label'   => __( 'Site Font', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Open Sans'
	);	

	$options['header-fixed-on'] = array(
		'id' => 'header-fixed-on',
		'label'   => __( 'Fixed site header bar', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['header-search-on'] = array(
		'id' => 'header-search-on',
		'label'   => __( 'Dispay header search', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['header-upload-on'] = array(
		'id' => 'header-upload-on',
		'label'   => __( 'Display header upload button', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);		

	$options['header-upload-url'] = array(
		'id' => 'header-upload-url',
		'label'   => __( 'Upload Button URL', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'url',
		'default' => home_url(),
	);		

	$options['featured-on'] = array(
		'id' => 'featured-on',
		'label'   => __( 'Display featured content on homepage', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['featured-num'] = array(
		'id' => 'featured-num',
		'label'   => __( 'Number of featured posts to show:', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $featured_num_choices,		
		'default' => '2',
	);	

	$options['all-posts-url'] = array(
		'id' => 'all-posts-url',
		'label'   => __( 'Page URL to display all recent posts', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'url',
		'default' => home_url() . '/latest',
	);	

	$options['home-button-on'] = array(
		'id' => 'home-button-on',
		'label'   => __( 'Display a button under home blocks', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['home-button-text'] = array(
		'id' => 'home-button-text',
		'label'   => __( 'Button Text', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'Browse our latest videos',
	);	

	$options['home-button-url'] = array(
		'id' => 'home-button-url',
		'label'   => __( 'Button URL', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'url',
		'default' => home_url() . '/latest',
	);		

	$options['date-format'] = array(
		'id' => 'date-format',
		'label'   => __( 'Post date format', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $date_format_choices,
		'default' => 'choice-1'
	);		

	$options['footer-widgets-on'] = array(
		'id' => 'footer-widgets-on',
		'label'   => __( 'Display footer widgets', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['related-posts-on'] = array(
		'id' => 'related-posts-on',
		'label'   => __( 'Display related posts on single posts', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['back-top-on'] = array(
		'id' => 'back-top-on',
		'label'   => __( 'Display "back to top" icon link on the site bottom', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);		

	$options['footer-credit'] = array(
		'id' => 'footer-credit',
		'label'   => __( 'Customize Site Footer Text/Link', 'fastvideo-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => '&copy;' . date("o") . ' - <a href="https://www.happythemes.com/wordpress-themes/fastvideo/">FastVideo Pro Theme</a> by <a href="https://www.happythemes.com">HappyThemes</a>'
	);			

	//$options['example-range'] = array(
	//	'id' => 'example-range',
	//	'label'   => __( 'Example Range Input', 'fastvideo-pro' ),
	//	'section' => $section,
	//	'type'    => 'range',
	//	'input_attrs' => array(
	//      'min'   => 0,
	//        'max'   => 10,
	//        'step'  => 1,
	//       'style' => 'color: #0a0',
	//	)
	//);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_demo_options' );